@@ -39,6 +39,8 @@ from bitmovin_api_sdk.models.ad_analytics_sum_query_request import AdAnalyticsSu
 from bitmovin_api_sdk.models.ad_analytics_variance_query_request import AdAnalyticsVarianceQueryRequest
 from bitmovin_api_sdk.models.adaptation_set import AdaptationSet
 from bitmovin_api_sdk.models.adaptation_set_role import AdaptationSetRole
+from bitmovin_api_sdk.models.adaptation_set_type import AdaptationSetType
+from bitmovin_api_sdk.models.adaptation_set_type_response import AdaptationSetTypeResponse
 from bitmovin_api_sdk.models.adaptive_quant_mode import AdaptiveQuantMode
 from bitmovin_api_sdk.models.aes_encryption_drm import AesEncryptionDrm
 from bitmovin_api_sdk.models.aes_encryption_method import AesEncryptionMethod
@@ -591,6 +593,19 @@ from bitmovin_api_sdk.models.sidecar_error_mode import SidecarErrorMode
 from bitmovin_api_sdk.models.sidecar_file import SidecarFile
 from bitmovin_api_sdk.models.sidecar_file_type import SidecarFileType
 from bitmovin_api_sdk.models.signature_type import SignatureType
+from bitmovin_api_sdk.models.simple_encoding_vod_job_access_key_credentials import SimpleEncodingVodJobAccessKeyCredentials
+from bitmovin_api_sdk.models.simple_encoding_vod_job_azure_credentials import SimpleEncodingVodJobAzureCredentials
+from bitmovin_api_sdk.models.simple_encoding_vod_job_credentials import SimpleEncodingVodJobCredentials
+from bitmovin_api_sdk.models.simple_encoding_vod_job_errors import SimpleEncodingVodJobErrors
+from bitmovin_api_sdk.models.simple_encoding_vod_job_gcs_service_account_credentials import SimpleEncodingVodJobGcsServiceAccountCredentials
+from bitmovin_api_sdk.models.simple_encoding_vod_job_input_type import SimpleEncodingVodJobInputType
+from bitmovin_api_sdk.models.simple_encoding_vod_job_request import SimpleEncodingVodJobRequest
+from bitmovin_api_sdk.models.simple_encoding_vod_job_response import SimpleEncodingVodJobResponse
+from bitmovin_api_sdk.models.simple_encoding_vod_job_s3_role_based_credentials import SimpleEncodingVodJobS3RoleBasedCredentials
+from bitmovin_api_sdk.models.simple_encoding_vod_job_status import SimpleEncodingVodJobStatus
+from bitmovin_api_sdk.models.simple_encoding_vod_job_url_input import SimpleEncodingVodJobUrlInput
+from bitmovin_api_sdk.models.simple_encoding_vod_job_url_output import SimpleEncodingVodJobUrlOutput
+from bitmovin_api_sdk.models.simple_encoding_vod_job_username_password_credentials import SimpleEncodingVodJobUsernamePasswordCredentials
 from bitmovin_api_sdk.models.smooth_manifest_content_protection import SmoothManifestContentProtection
 from bitmovin_api_sdk.models.smooth_manifest_default import SmoothManifestDefault
 from bitmovin_api_sdk.models.smooth_manifest_default_version import SmoothManifestDefaultVersion
